icsemantic.catalog.criteria.related.ATRelatedCriterion

Package platecom :: Package ontocatalog :: Package criteria :: Module related :: Class ATRelatedCriterion |
[hide private]
[frames] | no frames]

# Class ATRelatedCriterion

source code

    Products.ATContentTypes.criteria.base.ATBaseCriterion --+
                                                            |
                                                           ATRelatedCriterion

A related text criterion

Instance Methods | [hide private]
getCriteriaItems(self) | source code

Class Variables | [hide private]
| __implements__ = `ATBaseCriterion.__implements__+(IATTopicSearc`...``
| security = `ClassSecurityInfo()`
| schema = `ATBaseCriterionSchema+ Schema((StringField('value', r`...``
| meta_type = `'ATRelatedCriterion'`
| archetype_name = `'Friendly Related Criterion'`
| shortDesc = `'Related Criterion'`

Class Variable Details | [hide private]

  ### __implements__ Value:
      ATBaseCriterion.__implements__+(IATTopicSearchCriterion,)

  ### schema Value:
      ATBaseCriterionSchema+ Schema((StringField('value', required= 1, mode=
       "rw", write_permission= ChangeTopics, accessor= "Value", mutator= "se
      tValue", default= "", widget= StringWidget(label= _(u'label_related_cr
      iterion_value', default= u'Value'), description= _(u'help_related_crit
      erion_value', default= u'A string value.'))), StringField('context', r
      equired= 0, mode= "rw", write_permission= ChangeTopics, accessor= "Con
      text", mutator= "setContext", default= "", widget= StringWidget(label=
       _(u'label_related_criterion_value', default= u'Context'), description
      ...